import numpy as np
import pandas as pd
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from matplotlib import rcParams

rcParams["text.usetex"] = True
rcParams["font.serif"] = "Times New Roman"
rcParams["font.family"] = "Serif"
rcParams["xtick.labelsize"]=28
rcParams["ytick.labelsize"]=28
rcParams["legend.fontsize"]=28
rcParams["axes.labelsize"]=28

fig = plt.figure(figsize=(10,6))
ax = fig.add_subplot(111)

plp_df = pd.read_csv('O1O2O3a_plp_det.csv',sep=' ')
plp_df = plp_df[(plp_df['wave']==1) & (plp_df['ifar'] > (60*60*24*365.25))]

det_df = pd.read_csv('O1O2O3a_live_det.csv',sep=' ')

snr_min = 5.0
snr_max = 30.0
freq_min = 30
freq_max = 150

from matplotlib.colors import LogNorm
#plot heat map of model detections
h = plt.hist2d(plp_df['frequency0'], plp_df['rho1'], bins=500, norm=LogNorm())
cbar = plt.colorbar(h[3])
cbar.set_label('Count')

for i, txt in enumerate(det_df['ID']):
    if( txt=='GW190706'):
        ax.annotate('GW190706\_222641', (freq_min+3.0, snr_min+13.0), color='black', size=20, bbox=dict(facecolor='white', edgecolor='black', alpha=0.9))
        plt.arrow(det_df['frequency0'][i], det_df['rho1'][i], freq_min+3.0 - det_df['frequency0'][i] + 7.0, snr_min+13.0 - det_df['rho1'][i], head_starts_at_zero=True)
    if( txt=='GW190602'):
        ax.annotate('GW190602\_175927', (freq_min+3.0, snr_min+10.0), color='black', size=20, bbox=dict(facecolor='white', edgecolor='black', alpha=0.9))
        plt.arrow(det_df['frequency0'][i], det_df['rho1'][i], freq_min+3.0 - det_df['frequency0'][i] + 7.0, snr_min+10.0 - det_df['rho1'][i], head_starts_at_zero=True)
    if( txt=='GW190521'):
        ax.annotate(txt, (freq_min+3.0, snr_min+7.0), color='black', size=20, bbox=dict(facecolor='white', edgecolor='black', alpha=0.9))
        plt.arrow(det_df['frequency0'][i], det_df['rho1'][i], freq_min+3.0 - det_df['frequency0'][i] + 7.0, snr_min+7.0 - det_df['rho1'][i], head_starts_at_zero=True)

#plot cWB O3a detections
plt.scatter(det_df['frequency0'], det_df['rho1'], s=60, c='mediumvioletred', marker='x', linewidth=2.0)
plt.ylim(snr_min, snr_max)
plt.xlim(freq_min, freq_max)
plt.ylabel('Coherent SNR')
plt.xlabel('Central frequency [Hz]')
plt.grid(which='both',axis='x')
plt.grid(which='both',axis='y')
plt.tight_layout()
plt.savefig('./cwb_snr_freq_plot.png')
plt.savefig('./cwb_snr_freq_plot.pdf')
plt.close()



